@@ -3,9 +3,11 @@ mod event_record;
 mod parse_info;
 mod registers;
 mod sample;
+mod thread_map;
 
 pub use common_data::*;
 pub use event_record::*;
 pub use parse_info::*;
 pub use registers::*;
 pub use sample::*;
+pub use thread_map::*;
